@@ -37,22 +37,22 @@ func (a Adapter) GetPingStatement() string {
 func (a Adapter) GetColumnTypeDefinition(col *message.ColumnMetaData) *internal.Column {
 
 	column := &internal.Column{
-		Name:     col.ColumnName,
-		TypeName: col.Type.Name,
-		Nullable: col.Nullable != 0,
+		Name:     col.GetColumnName(),
+		TypeName: col.GetType().GetName(),
+		Nullable: col.GetNullable() != 0,
 	}
 
 	// Handle precision and length
-	switch col.Type.Name {
+	switch col.GetType().GetName() {
 	case "DECIMAL", "NUMERIC":
 
-		precision := int64(col.Precision)
+		precision := int64(col.GetPrecision())
 
 		if precision == 0 {
 			precision = math.MaxInt64
 		}
 
-		scale := int64(col.Scale)
+		scale := int64(col.GetScale())
 
 		if scale == 0 {
 			scale = math.MaxInt64
@@ -63,11 +63,11 @@ func (a Adapter) GetColumnTypeDefinition(col *message.ColumnMetaData) *internal.
 			Scale:     scale,
 		}
 	case "VARCHAR", "CHAR", "CHARACTER", "BINARY", "VARBINARY", "BIT", "BITVARYING":
-		column.Length = int64(col.Precision)
+		column.Length = int64(col.GetPrecision())
 	}
 
 	// Handle scan types
-	switch col.Type.Name {
+	switch col.GetType().GetName() {
 	case "INTEGER", "BIGINT", "TINYINT", "SMALLINT":
 		column.ScanType = reflect.TypeOf(int64(0))
 
@@ -91,7 +91,7 @@ func (a Adapter) GetColumnTypeDefinition(col *message.ColumnMetaData) *internal.
 	}
 
 	// Handle rep type special cases for decimals, floats, date, time and timestamp
-	switch col.Type.Name {
+	switch col.GetType().GetName() {
 	case "DECIMAL", "NUMERIC":
 		column.Rep = message.Rep_BIG_DECIMAL
 	case "FLOAT":
@@ -103,7 +103,7 @@ func (a Adapter) GetColumnTypeDefinition(col *message.ColumnMetaData) *internal.
 	case "TIMESTAMP":
 		column.Rep = message.Rep_JAVA_SQL_TIMESTAMP
 	default:
-		column.Rep = col.Type.Rep
+		column.Rep = col.GetType().GetRep()
 	}
 
 	return column
@@ -111,11 +111,11 @@ func (a Adapter) GetColumnTypeDefinition(col *message.ColumnMetaData) *internal.
 
 func (a Adapter) ErrorResponseToResponseError(err *message.ErrorResponse) errors.ResponseError {
 	return errors.ResponseError{
-		Exceptions:   err.Exceptions,
-		ErrorMessage: err.ErrorMessage,
-		Severity:     int8(err.Severity),
-		ErrorCode:    errors.ErrorCode(err.ErrorCode),
-		SqlState:     errors.SQLState(err.SqlState),
+		Exceptions:   err.GetExceptions(),
+		ErrorMessage: err.GetErrorMessage(),
+		Severity:     int8(err.GetSeverity()),
+		ErrorCode:    errors.ErrorCode(err.GetErrorCode()),
+		SqlState:     errors.SQLState(err.GetSqlState()),
 		Metadata: &errors.RPCMetadata{
 			ServerAddress: message.ServerAddressFromMetadata(err),
 		},
